@@ -1,5 +1,5 @@
 import pytest_check as check
-from shapely.geometry import Polygon
+from shapely import Polygon
 from sectionproperties.pre.geometry import Geometry
 import sectionproperties.pre.library.primitive_sections as sections
 import sectionproperties.pre.library.steel_sections as steel_sections
